@@ -2,11 +2,12 @@
 Usage:
 pyb-init local
 pyb-init github <user> : <project>
+pyb-init git <git_url>
 
 -h --help    show this
 '''
 from __future__ import absolute_import
-__version__ = '0.1.0'
+__version__ = '0.1.2'
 
 from docopt import docopt
 from pyb_init import reactor
@@ -20,6 +21,8 @@ def entry_point():
     if parsed_command_line['github']:
         task_reactor = reactor.for_github_clone(user=parsed_command_line['<user>'],
                                                 project=parsed_command_line['<project>'])
+    if parsed_command_line['git']:
+        task_reactor = reactor.for_git_clone(git_url=parsed_command_line['<git_url>'])
 
     for task in task_reactor.get_tasks():
         task.execute()
